@@ -5,7 +5,7 @@
 #define QT_FEATURE_futimens 1
 #define QT_FEATURE_futimes -1
 #define QT_FEATURE_getauxval 1
-#define QT_FEATURE_getentropy 1
+#define QT_FEATURE_getentropy -1
 #define QT_FEATURE_glib 1
 #define QT_FEATURE_posix_libiconv 1
 #define QT_FEATURE_gnu_libiconv -1
